@@ -1,12 +1,12 @@
 #' 
-#' dataset01
+#' TONY FROC dataset
 #'
 #' This is referred to in the book as the "TONY" dataset. It consists of 185 cases, 
-#' 89 of which are diseased, interpreted in two modalities
+#' 89 of which are diseased, interpreted in two treatments
 #' ("BT" = breast tomosynthesis and "DM" = digital mammography) by five radiologists using the FROC paradigm. 
 #' The diseased cases had at most two cancers (lesions) per case while the maximum number of 
 #' non-lesion localizations (NLs) per case, over the entire dataset, was 3. The example below displays
-#' the wAFROC plot for the first modality and first reader.
+#' the wAFROC plot for the first treatment and first reader.
 #' 
 #' @format A list with 8 elements:
 #' \itemize{
@@ -16,7 +16,7 @@
 #' \item{\code{lesionID}}{ array [1:89, 1:2], labels of lesions on diseased cases}
 #' \item{\code{lesionWeight}}{ array [1:89, 1:2], weights (or clinical importance) of lesions}
 #' \item{\code{dataType}}{ "FROC", the data type}
-#' \item{\code{modalityID}}{ [1:2] "BT" "DM", modality labels}
+#' \item{\code{modalityID}}{ [1:2] "BT" "DM", treatment labels}
 #' \item{\code{readerID}}{ [1:5] "1" "2" "3" "4" ..., reader labels}
 #' }
 #'
@@ -32,16 +32,17 @@
 #'
 "dataset01"
 #'
-#' dataset02
+#'
+#' Van Dyke ROC dataset
 #'
 #' This is referred to in the book as the "VD" dataset. It consists of 114 cases,
-#'    45 of which are diseased, interpreted in two modalities ("0" = single spin echo 
+#'    45 of which are diseased, interpreted in two treatments ("0" = single spin echo 
 #'    MRI, "1" = cine-MRI) by five radiologists using the ROC 
 #'    paradigm. Each diseased cases had an aortic dissection; the ROC paradigm 
 #'    generates one rating per case.  Often referred to in the ROC literature as the 
 #'    Van Dyke dataset, which, along with the Franken dataset, has been widely 
 #'    used to illustrate advances in ROC methodology. The example below displays 
-#'    the ROC plot for the first modality and first reader.
+#'    the ROC plot for the first treatment and first reader.
 #' 
 #' @format A list with 8 elements:
 #' \itemize{
@@ -51,7 +52,7 @@
 #' \item{\code{lesionID}}{ array [1:45, 1], labels of lesions on diseased cases, all set to 1}
 #' \item{\code{lesionWeight}}{ array [1:45, 1], weights (or clinical importance) of lesions, all set to 1}
 #' \item{\code{dataType}}{ "ROC", the data type}
-#' \item{\code{modalityID}}{ [1:2] "0" "1", modality labels}
+#' \item{\code{modalityID}}{ [1:2] "0" "1", treatment labels}
 #' \item{\code{readerID}}{ [1:5] "0" "1" "2" ..., reader labels}
 #' }
 #'
@@ -68,10 +69,11 @@
 #'
 "dataset02"
 #' 
-#' dataset03
+#' 
+#' Franken ROC dataset
 #'
 #' This is referred to in the book as the "FR" dataset. It consists of 100 cases, 
-#' 69 of which are diseased, interpreted in two modalities,
+#' 69 of which are diseased, interpreted in two treatments,
 #' "0" = conventional film radiographs, "1" = digitized  images viewed on monitors, by four 
 #' radiologists using the ROC paradigm. Often referred to in the ROC literature as the 
 #' Franken-dataset, which, along the the Van Dyke dataset, has been widely used to illustrate
@@ -85,7 +87,7 @@
 #' \item{\code{lesionID}}{ array [1:67, 1], labels of lesions on diseased cases, all set to 1}
 #' \item{\code{lesionWeight}}{ array [1:67, 1], weights (or clinical importance) of lesions, all set to 1}
 #' \item{\code{dataType}}{ "ROC", the data type}
-#' \item{\code{modalityID}}{ [1:2] "0" "1", modality labels}
+#' \item{\code{modalityID}}{ [1:2] "0" "1", treatment labels}
 #' \item{\code{readerID}}{ [1:4] "0" "1" "2" ..., reader labels}
 #' }
 #'
@@ -102,11 +104,12 @@
 #'
 "dataset03"
 #'
-#' dataset04
+#'
+#' Federica Zanca FROC dataset
 #'
 #' This is referred to in the book as the "FED" dataset. It consists of 200 mammograms, 
 #' 100 of which contained one to 3 simulated microcalcifications,
-#' interpreted in five modalities (basically different image processing algorithms), by four 
+#' interpreted in five treatments (basically different image processing algorithms), by four 
 #' radiologists using the FROC paradigm. The maximum number of NLs per case, over the entire 
 #' dataset was 7 and the dataset contained at least one diseased mammogram with 3 lesions.
 #' 
@@ -118,7 +121,7 @@
 #' \item{\code{lesionID}}{ array [1:100, 1:3], labels of lesions on diseased cases, all set to 1}
 #' \item{\code{lesionWeight}}{ array [1:100, 1:3] weights (or clinical importance) of lesions, all set to 1}
 #' \item{\code{dataType}}{ "FROC", the data type}
-#' \item{\code{modalityID}}{ [1:5] "1" "2" ... modality labels}
+#' \item{\code{modalityID}}{ [1:5] "1" "2" ... treatment labels}
 #' \item{\code{readerID}}{ [1:4] "1" "3" "4" "5" reader labels}
 #' }
 #'
@@ -134,10 +137,11 @@
 #'
 "dataset04"
 #'
-#' dataset05
+#'
+#' John Thompson FROC dataset
 #'
 #' This is referred to in the book as the "JT" dataset. It consists of 92 cases, 47 of 
-#' which are diseased, interpreted in two modalities 
+#' which are diseased, interpreted in two treatments 
 #' ("1" = CT images acquired for attenuation correction, "2" = diagnostic CT images), by nine 
 #' radiographers using the FROC paradigm. Each case was a slice of an anthropomorphic phantom
 #' 47 with inserted nodular lesions (max 3 per slice). The maximum number of NLs per case, over the entire 
@@ -151,7 +155,7 @@
 #' \item{\code{lesionID}}{ array [1:47, 1:3], labels of lesions on diseased cases, all set to 1}
 #' \item{\code{lesionWeight}}{ array [1:67, 1] weights (or clinical importance) of lesions, all set to 1}
 #' \item{\code{dataType}}{ "FROC", the data type}
-#' \item{\code{modalityID}}{ [1:2] "1" "2", modality labels}
+#' \item{\code{modalityID}}{ [1:2] "1" "2", treatment labels}
 #' \item{\code{readerID}}{ [1:4] "1" "2" "3" "4", reader labels}
 #' }
 #'
@@ -159,7 +163,7 @@
 #'
 #' @references Thompson JD  et al. Effect of reconstruction methods and x-ray tube 
 #' current-time product  on nodule detection in an anthropomorphic thorax phantom: 
-#' a crossed-modality JAFROC observer study. Medical Physics. 2016;43(3):1265-1274.
+#' a crossed-treatment JAFROC observer study. Medical Physics. 2016;43(3):1265-1274.
 #' 
 #' @examples
 #' str(dataset05)
@@ -168,11 +172,12 @@
 #'
 "dataset05"
 #'
-#' dataset06
+#'
+#' Magnus FROC dataset
 #'
 #' This is referred to in the book as the "MAG" dataset (after Magnus Bath, 
 #' who conducted the JAFROC analysis). It consists of 100 cases, 69 of which are diseased, 
-#' interpreted in two modalities ("1" = conventional chest, "1" = chest tomosynthesis) by four 
+#' interpreted in two treatments ("1" = conventional chest, "1" = chest tomosynthesis) by four 
 #' radiologists using the FROC paradigm.  
 #' 
 #' @format A list with 8 elements:
@@ -183,7 +188,7 @@
 #' \item{\code{lesionID}}{ array [1:42, 1:15], labels of lesions on diseased cases, all set to 1}
 #' \item{\code{lesionWeight}}{ array [1:42, 1:15] weights (or clinical importance) of lesions, all set to 1}
 #' \item{\code{dataType}}{ "FROC", the data type}
-#' \item{\code{modalityID}}{ [1:2] "1" "2", modality labels}
+#' \item{\code{modalityID}}{ [1:2] "1" "2", treatment labels}
 #' \item{\code{readerID}}{ [1:4] "1" "2" ..., reader labels}
 #' }
 #'
@@ -199,10 +204,12 @@
 #'
 #'
 "dataset06"
-#' dataset07
+#' 
+#' 
+#' Lucy Warren FROC dataset
 #'
 #' This is referred to in the book as the "OPT" dataset (for OptiMam). It consists of 162 cases, 
-#' 81 of which are diseased, interpreted in five modalities (see reference, basically different ways
+#' 81 of which are diseased, interpreted in five treatments (see reference, basically different ways
 #' of acquiring the images) by seven radiologists using the FROC paradigm.  
 #' 
 #' @format A list with 8 elements:
@@ -213,7 +220,7 @@
 #' \item{\code{lesionID}}{ array [1:81, 1:3], labels of lesions on diseased cases, all set to 1}
 #' \item{\code{lesionWeight}}{ array [1:81, 1:3] weights (or clinical importance) of lesions, all set to 1}
 #' \item{\code{dataType}}{ "FROC", the data type}
-#' \item{\code{modalityID}}{ [1:5] "1" "2", ..., modality labels}
+#' \item{\code{modalityID}}{ [1:5] "1" "2", ..., treatment labels}
 #' \item{\code{readerID}}{ [1:7] "1" "2" ..., reader labels}
 #' }
 #'
@@ -230,10 +237,11 @@
 #'
 "dataset07"
 #'
-#' dataset08
+#'
+#' Monica Penedo ROC dataset
 #'
 #' This is referred to in the book as the "PEN" dataset. It consists of 112 cases, 
-#' 64 of which are diseased, interpreted in five modalities (basically different image compression
+#' 64 of which are diseased, interpreted in five treatments (basically different image compression
 #' algorithms) by five 
 #' radiologists using the FROC paradigm (the inferred ROC dataset is included; the original FROC data
 #' is lost). 
@@ -246,7 +254,7 @@
 #' \item{\code{lesionID}}{ array [1:64, 1], labels of lesions on diseased cases, all set to 1}
 #' \item{\code{lesionWeight}}{ array [1:64, 1], weights (or clinical importance) of lesions, all set to 1}
 #' \item{\code{dataType}}{ "ROC", the data type}
-#' \item{\code{modalityID}}{ [1:5] "0" "1", modality labels}
+#' \item{\code{modalityID}}{ [1:5] "0" "1", treatment labels}
 #' \item{\code{readerID}}{ [1:5] "0" "1" "2" ..., reader labels}
 #' }
 #'
@@ -263,13 +271,15 @@
 #'
 #'
 "dataset08"
-#' dataset09
+#' 
+#' 
+#' Nico Karssemeijer ROC dataset (CAD vs. radiologists)
 #'
 #' This is referred to in the book as the "NICO" dataset. It consists of 200 mammograms, 
 #' 80 of which contain one malignant mass, 
 #' interpreted by a CAD system and nine radiologists using the 
 #' LROC paradigm. The first reader is CAD. The highest rating method was used to convert this to an ROC 
-#' dataset. The original LROC data is \code{datasetCadLroc}. Analyzing this \strong{one-modality}
+#' dataset. The original LROC data is \code{datasetCadLroc}. Analyzing this \strong{one-treatment}
 #' data requires methods described in the book, specifically, the function  
 #' \link{StSignificanceTestingSingleFixedFactor} analyzes such datasets.
 #' 
@@ -281,7 +291,7 @@
 #' \item{\code{lesionID}}{ array [1:80, 1], labels of lesions on diseased cases, all set to 1}
 #' \item{\code{lesionWeight}}{ array [1:80, 1], weights (or clinical importance) of lesions, all set to 1}
 #' \item{\code{dataType}}{ "ROC", the data type}
-#' \item{\code{modalityID}}{ [1] "1" modality label}
+#' \item{\code{modalityID}}{ [1] "1" treatment label}
 #' \item{\code{readerID}}{ [1:10] "1" "2" ..., reader labels}
 #' }
 #'
@@ -297,11 +307,12 @@
 #'
 "dataset09"
 #'
-#' dataset10
+#'
+#' Marc Ruschin ROC dataset
 #'
 #' This is referred to in the book as the "RUS" dataset. It consists of 90 cases, 
 #' 40 of which are diseased, the images were
-#' acquired at three dose levels, which can be regarded as modalities.
+#' acquired at three dose levels, which can be regarded as treatments.
 #' "0" = conventional film radiographs, "1" = digitized  images viewed on monitors, Eight 
 #' radiologists interpreted the cases using the FROC paradigm. These have been reduced to 
 #' ROC data by using the highest ratings (the original FROC data is lost). 
@@ -314,7 +325,7 @@
 #' \item{\code{lesionID}}{ array [1:40, 1], labels of lesions on diseased cases, all set to 1}
 #' \item{\code{lesionWeight}}{ array [1:40, 1], weights (or clinical importance) of lesions, all set to 1}
 #' \item{\code{dataType}}{ "ROC", the data type}
-#' \item{\code{modalityID}}{ [1:3] "1" "2" "3", modality labels}
+#' \item{\code{modalityID}}{ [1:3] "1" "2" "3", treatment labels}
 #' \item{\code{readerID}}{ [1:8] "1" "2" ..., reader labels}
 #' }
 #'
@@ -331,7 +342,9 @@
 #'
 #'
 "dataset10"
-#' dataset11
+#' 
+#' 
+#' Dobbins 1 FROC dataset
 #'
 #' This is referred to in the book as the "DOB1" dataset. Dobbins et al conducted a 
 #' multi-institutional, MRMC study to compare the performance of digital tomosynthesis 
@@ -342,7 +355,7 @@
 #' the rest had 1 - 20 pulmonary nodules independently verified, using with CT 
 #' images, by 3 experts who did not participate in the observer study. The 
 #' study used FROC paradigm data collection. There are 
-#' 4 modalities labeled 1 - 4 (conventional chest x-ray, CXR, CXR augmented
+#' 4 treatments labeled 1 - 4 (conventional chest x-ray, CXR, CXR augmented
 #' with dual-energy (CXR+DE), VolumeRad digital tomosynthesis images and 
 #' VolumeRad augmented with DE (VolumeRad+DE). 
 #' 
@@ -354,7 +367,7 @@
 #' \item{\code{lesionID}}{ array [1:115, 20], labels of lesions on diseased cases, all set to 1}
 #' \item{\code{lesionWeight}}{ array [1:115, 20] weights (or clinical importance) of lesions, all set to 1}
 #' \item{\code{dataType}}{ "FROC", the data type}
-#' \item{\code{modalityID}}{ [1:4] "1" "2" ..., modality labels}
+#' \item{\code{modalityID}}{ [1:4] "1" "2" ..., treatment labels}
 #' \item{\code{readerID}}{ [1:5] "1" "2" ..., reader labels}
 #' }
 #'
@@ -370,7 +383,8 @@
 #'
 "dataset11"
 #'
-#' dataset12
+#'
+#' Dobbins 2 ROC dataset
 #'
 #' This is referred to in the code as the "DOB2" dataset. It contains actionability
 #' ratings, i.e., do you recommend further follow up on the patient, one a 1 (definitely not)
@@ -384,7 +398,7 @@
 #' \item{\code{lesionID}}{ array [1:88, 1], labels of lesions on diseased cases, all set to 1}
 #' \item{\code{lesionWeight}}{ array [1:88, 1], weights (or clinical importance) of lesions, all set to 1}
 #' \item{\code{dataType}}{ "ROC", the data type}
-#' \item{\code{modalityID}}{ [1:2] "0" "1", modality labels}
+#' \item{\code{modalityID}}{ [1:2] "0" "1", treatment labels}
 #' \item{\code{readerID}}{ [1:4] "0" "1" "2" ..., reader labels}
 #' }
 #'
@@ -399,10 +413,12 @@
 #'
 #'
 "dataset12"
-#' dataset13
+#' 
+#' 
+#' Dobbins 3 FROC dataset
 #'
 #' This is referred to in the code as the "DOB3" dataset. This is a subset of DOB1 which includes
-#' data for lesions not-visible on CXR, but visible to truth panel on all modalities.  
+#' data for lesions not-visible on CXR, but visible to truth panel on all treatments.  
 #' 
 #' @format A list with 8 elements:
 #' \itemize{
@@ -412,7 +428,7 @@
 #' \item{\code{lesionID}}{ array [1:106, 15], labels of lesions on diseased cases, all set to 1}
 #' \item{\code{lesionWeight}}{ array [1:106, 15] weights (or clinical importance) of lesions, all set to 1}
 #' \item{\code{dataType}}{ "FROC", the data type}
-#' \item{\code{modalityID}}{ [1:4] "1" "2" ..., modality labels}
+#' \item{\code{modalityID}}{ [1:4] "1" "2" ..., treatment labels}
 #' \item{\code{readerID}}{ [1:5] "1" "2" ..., reader labels}
 #' }
 #'
@@ -428,10 +444,11 @@
 #'
 "dataset13"
 #'
-#' dataset14
+#'
+#' Federica Zanca real (as opposed to inferred) ROC dataset
 #'
 #' This is referred to in the book as the "FZR" dataset. It is a real ROC study, 
-#' conducted on the same images and using the same radiologists, on modalities
+#' conducted on the same images and using the same radiologists, on treatments
 #' "4" and "5" of dataset04. This was compared to highest rating inferred ROC
 #' data from dataset04 to conclude, erroneously, that the highest rating assumption
 #' is invalid. See book Section 13.6.2.
@@ -444,7 +461,7 @@
 #' \item{\code{lesionID}}{ array [1:100, 1], labels of lesions on diseased cases, all set to 1}
 #' \item{\code{lesionWeight}}{ array [1:100, 1], weights (or clinical importance) of lesions, all set to 1}
 #' \item{\code{dataType}}{ "ROC", the data type}
-#' \item{\code{modalityID}}{ [1:2] "1" "2", modality labels}
+#' \item{\code{modalityID}}{ [1:2] "1" "2", treatment labels}
 #' \item{\code{readerID}}{ [1:4] "1" "2" ..., reader labels}
 #' }
 #'
@@ -460,7 +477,9 @@
 #'
 #'
 "dataset14"
-#' datasetCadLroc
+#' 
+#' 
+#' Nico Karssemeijer LROC dataset (CAD vs. radiologists)
 #'
 #' This is the actual LROC data corresponding to \code{dataset09}, which was the inferred
 #' ROC data. Note that the \code{LL} field is split into two, \code{LLCl}, representing true 
@@ -478,7 +497,7 @@
 #' \item{\code{lesionID}}{ array [1:80, 1], labels of lesions on diseased cases, all set to 1}
 #' \item{\code{lesionWeight}}{ array [1:80, 1], weights (or clinical importance) of lesions, all set to 1}
 #' \item{\code{dataType}}{ "LROC", the data type}
-#' \item{\code{modalityID}}{ [1:2] "0" "1", modality labels}
+#' \item{\code{modalityID}}{ [1:2] "0" "1", treatment labels}
 #' \item{\code{readerID}}{ [1:10] "1" "2" ..., reader labels}
 #' }
 #'
@@ -493,11 +512,12 @@
 #'
 "datasetCadLroc"
 #'
-#' datasetCrossedModality
+#' 
+#' John Thompson crossed treatment FROC dataset
 #'
-#' This is a crossed modality dataset, see book Section 18.5. There are two modality factors. 
-#' The first modality factor \code{modalityID1} can be "F" or "I", which represent two CT reconstruction
-#' algorithms. The second modality factor \code{modalityID2} can be "20" "40"  "60"  "80", which 
+#' This is a crossed treatment dataset, see book Section 18.5. There are two treatment factors. 
+#' The first treatment factor \code{modalityID1} can be "F" or "I", which represent two CT reconstruction
+#' algorithms. The second treatment factor \code{modalityID2} can be "20" "40"  "60"  "80", which 
 #' represent the mAs values of the image acquisition. The factors are fully crossed. The function 
 #' \link{StSignificanceTestingCrossedModalities} analyzes such datasets.
 #' 
@@ -509,8 +529,8 @@
 #' \item{\code{lesionID}}{ array [1:34, 3], labels of lesions on diseased cases, all set to 1}
 #' \item{\code{lesionWeight}}{ array [1:34, 3] weights (or clinical importance) of lesions, all set to 1}
 #' \item{\code{dataType}}{ "FROC", the data type}
-#' \item{\code{modalityID1}}{ [1:2] "F" "I", modality labels}
-#' \item{\code{modalityID2}}{ [1:4] "20" "40"  "60"  "80", modality labels}
+#' \item{\code{modalityID1}}{ [1:2] "F" "I", treatment labels}
+#' \item{\code{modalityID2}}{ [1:4] "20" "40"  "60"  "80", treatment labels}
 #' \item{\code{readerID}}{ [1:11] "1" "10" "11" ..., reader labels}
 #' }
 #'
@@ -518,7 +538,7 @@
 #'
 #' @references Thompson JD, Chakraborty DP, Szczepura K, et al. (2016) Effect of reconstruction 
 #' methods and x-ray tube current-time product  on nodule detection in an 
-#' anthropomorphic thorax phantom: a crossed-modality JAFROC observer study. 
+#' anthropomorphic thorax phantom: a crossed-treatment JAFROC observer study. 
 #' Medical Physics. 43(3):1265-1274.
 #' 
 #' @examples
@@ -526,7 +546,9 @@
 #'
 #'
 "datasetCrossedModality"
-#' datasetDegenerate
+#' 
+#' 
+#' Simulated degenerate ROC dataset; for testing purposes
 #'
 #' A simulated degenerated dataset. A degenerate dataset is defined as one with
 #' no interior operating points on the ROC plot. Such data tend to be observed with expert level 
@@ -541,7 +563,7 @@
 #' \item{\code{lesionID}}{ array [1:10, 1], labels of lesions on diseased cases, all set to 1}
 #' \item{\code{lesionWeight}}{ array [1:10, 1], weights (or clinical importance) of lesions, all set to 1}
 #' \item{\code{dataType}}{ "ROC", the data type}
-#' \item{\code{modalityID}}{ "1", modality label}
+#' \item{\code{modalityID}}{ "1", treatment label}
 #' \item{\code{readerID}}{ "1", reader label}
 #' }
 #'
@@ -552,7 +574,104 @@
 #'
 #'
 "datasetDegenerate"
+#'
+#' 
+#' Binned dataset suitable for checking \link{FitCorCbm}; seed = 123
+#'
+#' A binned dataset suitable for analysis by \link{FitCorCbm}. It was generated by
+#'    \link{DfCreateCorCbmDataset} by setting the \code{seed} variable to 123. Note
+#'    the formatting of the data as a single treatment two reader dataset, even though
+#'    the actual pairing might be different, see \link{FitCorCbm}. The dataset is 
+#'    intentionally large so as to demonstrate the asymptotic convergence of ML estimates, 
+#'    produced by \link{FitCorCbm}, to the population values. The data was generated
+#'    by the following argument values to \link{DfCreateCorCbmDataset}: seed = 123, 
+#'    K1 = 5000, K2 = 5000, desiredNumBins = 5, muX = 1.5, muY = 3, alphaX = 0.4, 
+#'    alphaY = 0.7, rhoNor = 0.3, rhoAbn2 = 0.8. 
+#' 
+#' @format A list with 8 elements:
+#' \itemize{
+#' \item{\code{NL}}{ Ratings array [1, 1:2, 1:10000, 1], of non-lesion localizations, NLs}
+#' \item{\code{LL}}{ Ratings array [1, 1:2, 1:5000, 1], of lesion localizations, LLs}
+#' \item{\code{lesionNum}}{ array [1:5000], number of lesions per diseased case, all set to one}
+#' \item{\code{lesionID}}{ array [1:5000, 1], lesions labels on diseased cases, all set to one}
+#' \item{\code{lesionWeight}}{ array [1:5000, 1], weights, all set to one}
+#' \item{\code{dataType}}{ "ROC", the data type}
+#' \item{\code{modalityID}}{ "1", treatment label}
+#' \item{\code{readerID}}{ [1:2] "1" "2",  reader labels}
+#' }
+#'
+#' @keywords datasets
+#'
+#' @references Zhai X, Chakraborty DP (2017). A bivariate contaminated binormal model for robust 
+#'    fitting of proper ROC curves to a pair of correlated, possibly degenerate, 
+#'    ROC datasets. Medical Physics. 44(6):2207--2222.
 
+#' @examples
+#' str(binnedData123)
+#'
+"binnedData123"
+#'
+#'
+#' Binned dataset suitable for checking \link{FitCorCbm}; seed = 124
+#'
+#' A binned dataset suitable for analysis by \link{FitCorCbm}. It was generated by
+#'    \link{DfCreateCorCbmDataset} by setting the \code{seed} variable to 124. 
+#'    Otherwise similar to \link{binnedData123}. 
+#' 
+#' @format A list with 8 elements:
+#' \itemize{
+#' \item{\code{NL}}{ Ratings array [1, 1:2, 1:10000, 1], of non-lesion localizations, NLs}
+#' \item{\code{LL}}{ Ratings array [1, 1:2, 1:5000, 1], of lesion localizations, LLs}
+#' \item{\code{lesionNum}}{ array [1:5000], number of lesions per diseased case, all set to one}
+#' \item{\code{lesionID}}{ array [1:5000, 1], lesions labels on diseased cases, all set to one}
+#' \item{\code{lesionWeight}}{ array [1:5000, 1], weights, all set to one}
+#' \item{\code{dataType}}{ "ROC", the data type}
+#' \item{\code{modalityID}}{ "1", treatment label}
+#' \item{\code{readerID}}{ [1:2] "1" "2",  reader labels}
+#' }
+#'
+#' @keywords datasets
+#'
+#' @references Zhai X, Chakraborty DP (2017). A bivariate contaminated binormal model for robust 
+#'    fitting of proper ROC curves to a pair of correlated, possibly degenerate, 
+#'    ROC datasets. Medical Physics. 44(6):2207--2222.
+
+#' @examples
+#' str(binnedData124)
+#'
+"binnedData124"
+#'
+#' 
+#' Binned dataset suitable for checking \link{FitCorCbm}; seed = 125
+#'
+#' A binned dataset suitable for analysis by \link{FitCorCbm}. It was generated by
+#'    \link{DfCreateCorCbmDataset} by setting the \code{seed} variable to 125. 
+#'    Otherwise similar to \link{binnedData123}. 
+#' 
+#' @format A list with 8 elements:
+#' \itemize{
+#' \item{\code{NL}}{ Ratings array [1, 1:2, 1:10000, 1], of non-lesion localizations, NLs}
+#' \item{\code{LL}}{ Ratings array [1, 1:2, 1:5000, 1], of lesion localizations, LLs}
+#' \item{\code{lesionNum}}{ array [1:5000], number of lesions per diseased case, all set to one}
+#' \item{\code{lesionID}}{ array [1:5000, 1], lesions labels on diseased cases, all set to one}
+#' \item{\code{lesionWeight}}{ array [1:5000, 1], weights, all set to one}
+#' \item{\code{dataType}}{ "ROC", the data type}
+#' \item{\code{modalityID}}{ "1", treatment label}
+#' \item{\code{readerID}}{ [1:2] "1" "2",  reader labels}
+#' }
+#'
+#' @keywords datasets
+#'
+#' @references Zhai X, Chakraborty DP (2017). A bivariate contaminated binormal model for robust 
+#'    fitting of proper ROC curves to a pair of correlated, possibly degenerate, 
+#'    ROC datasets. Medical Physics. 44(6):2207--2222.
+
+#' @examples
+#' str(binnedData125)
+#'
+"binnedData125"
+#'
+#'
 
 
 
